@@ -16,6 +16,8 @@ from urllib import request, parse
 from urllib.parse import quote, urlparse
 from collections import Counter
 
+import requests
+
 from bbcloud_python_sdk.FileCache import FileCache
 
 logging.basicConfig(level=logging.WARNING)
@@ -47,10 +49,20 @@ def execute(command, cwd='/'):
     :param cwd: 执行环境
     :return: 输出，错误信息(bytes类型)
     """
-    sub = subprocess.Popen(command, cwd=cwd, stdin=subprocess.PIPE, stdout=sys.stdout,
-                           stderr=subprocess.STDOUT, shell=True)
-    sub.communicate()
+    try:
+        return_info = subprocess.Popen(command,cwd=cwd,  shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
+        while True:
+            next_line = return_info.stdout.readline()
+            return_line = next_line.decode("utf-8", "ignore")
+            if return_line == '' and return_info.poll() != None:
+                break
+            print(return_line)
 
+        returncode = return_info.wait()
+        if returncode:
+            raise subprocess.CalledProcessError(returncode, return_info)
+    except Exception as e:
+        print(e)
 
 def delete_dir_then_move_dir(file_from, file_to):
     """
@@ -778,21 +790,35 @@ def unzip(file_name, dst_dir=None):
 
 
 def get_last_commit_sha_by_branch(git_host, git_token, git_project_id, git_branch):
-    url = '%s/api/v4/projects/%s/repository/commits/%s?private_token=%s' % (
-        git_host, git_project_id, quote(git_branch, 'utf-8'), git_token)
-    res = json.loads(request.urlopen(url).read())
-    if res:
-        return res['id']
+    url = '%s/api/v4/projects/%s/repository/commits/%s' % (
+        git_host, git_project_id, git_branch)
+    res = requests.request('GET', url,
+                           params={
+                               'private_token': git_token
+                           },
+                           stream=True)
+
+    if res.status_code == 200:
+        return json.loads(res.content)['id']
     else:
         raise Exception('commit sha get failure %s' % url)
 
 
 def get_gitlab_last_pipeline_id_by_branch(git_host, git_token, git_project_id, git_branch):
-    url = '%s/api/v4/projects/%s/pipelines?status=success&ref=%s&private_token=%s&per_page=1&order_by=id&sort=desc' % (
-        git_host, git_project_id, quote(git_branch, 'utf-8'), git_token)
-    logging.info(url)
-    res = json.loads(request.urlopen(url).read())
-    if len(res) == 1:
-        return res[0]['id']
+    url = '%s/api/v4/projects/%s/pipelines' % (
+        git_host, git_project_id)
+    res = requests.request('GET', url,
+                           params={
+                               'private_token': git_token,
+                               'status': 'success',
+                               'ref': git_branch,
+                               'per_page': 1,
+                               'order_by': 'id',
+                               'sort': 'desc'
+                           },
+                           stream=True)
+
+    if len(res) == 1 and res.status_code == 200:
+        return json.loads(res.content)[0]['id']
     else:
-        raise Exception('pipeline id get failure %s' % url)
+        raise Exception('pipeline id get failure %s %s' % (url, res.status_code))
